@@ -10,7 +10,7 @@
 #' @keywords spatial
 #' @keywords methods
 #' 
-#' @param x object of class 'Transition*'
+#' @param x object of class \code{Transition*}
 #' @param type type of correction: "c", "r", or missing 
 #'  (only required for lonlat, see Details)
 #' @param ... additional arguments passed to methods. \code{multpl} with 
@@ -161,7 +161,7 @@ setMethod("geoCorrection",
   correctionMatrix <- new("dgTMatrix", i = i, j = j, x = xv, 
                           Dim = as.integer(c(dims,dims)))
   correctionMatrix <- (methods::as(correctionMatrix,"sparseMatrix"))
-  if(class(transitionMatrix(x)) == "dsCMatrix"){
+  if(is(transitionMatrix(x), "dsCMatrix")){
     correctionMatrix <- forceSymmetric(correctionMatrix)
   }  #isSymmetric?
   if(!multpl) 
